@@ -57,9 +57,6 @@ class PinholeCameraModel(object):
         self.tf_frame = tf_frame
         self.stamp = stamp
 
-    def calc_f_from_fov(self, fov, length):
-        return length / (2.0 * np.tan(fov * np.pi / 360.0))
-
     @property
     def width(self):
         """Returns image width
@@ -282,6 +279,81 @@ class PinholeCameraModel(object):
             self.cy)
         return intrinsic
 
+    @staticmethod
+    def calc_fovx(fovy, height, width):
+        """Return fovx from fovy, height and width.
+
+        Parameters
+        ----------
+        fovy : float
+            field of view in degree.
+        height : int
+            height of camera.
+        width : int
+            width of camera.
+
+        Returns
+        -------
+        fovy : float
+            calculated fovx.
+        """
+        aspect = 1.0 * width / height
+        fovx = np.rad2deg(2 * np.arctan(
+            np.tan(0.5 * np.deg2rad(fovy)) * aspect))
+        return fovx
+
+    @staticmethod
+    def calc_f_from_fov(fov, aperture):
+        """Return focal length.
+
+        Parameters
+        ----------
+        fov : float
+            field of view in degree.
+        aperture : float
+            aperture.
+
+        Returns
+        -------
+        focal_length : float
+            calculated focal length.
+        """
+        return aperture / (2.0 * np.tan(np.deg2rad(fov / 2.0)))
+
+    @staticmethod
+    def from_fov(fovy, height, width, **kwargs):
+        """Return PinholeCameraModel from fov.
+
+        Parameters
+        ----------
+        fovy : float
+            horizontal field of view in degree.
+        height : int
+            height of camera.
+        width : int
+            width of camera.
+
+        Returns
+        -------
+        cameramodel : cameramodels.PinholeCameraModel
+            camera model
+        """
+        fovx = PinholeCameraModel.calc_fovx(fovy, height, width)
+        fy = PinholeCameraModel.calc_f_from_fov(fovy, height)
+        fx = PinholeCameraModel.calc_f_from_fov(fovx, width)
+        K = [fx, 0, width / 2.0,
+             0, fy, height / 2.0,
+             0, 0, 1]
+        P = [fx, 0, width / 2.0, 0,
+             0, fy, height / 2.0, 0,
+             0, 0, 1, 0]
+        return PinholeCameraModel(
+            image_height=height,
+            image_width=width,
+            K=K,
+            P=P,
+            **kwargs)
+
     @staticmethod
     def from_open3d_intrinsic(open3d_pinhole_intrinsic):
         """Return PinholeCameraModel from open3d's pinhole camera intrinsic.
